Helpers for comparing Datomic pull patterns with Glimpse access paths.
Helpers for comparing Datomic pull patterns with Glimpse access paths.
(compare-to-pattern accessed-paths pulled-paths)Compare accessed paths against paths that were fetched.
Returns: {:accessed-paths #{...} :over-fetched #{...} :under-fetched #{...}}
over-fetched contains pulled paths that were never read.
under-fetched contains read paths that were not in the pulled path set.
Compare accessed paths against paths that were fetched.
Returns:
{:accessed-paths #{...}
:over-fetched #{...}
:under-fetched #{...}}
`over-fetched` contains pulled paths that were never read.
`under-fetched` contains read paths that were not in the pulled path set.(pull-pattern->paths pattern)(pull-pattern->paths pattern prefix)Extract leaf paths from a Datomic pull pattern.
This intentionally handles the common pull-pattern shapes Glimpse needs for access comparison. It is not a full Datomic pull parser.
Extract leaf paths from a Datomic pull pattern. This intentionally handles the common pull-pattern shapes Glimpse needs for access comparison. It is not a full Datomic pull parser.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |